# DDGun
Untrained prediction of protein stability changes

### Original paper
DDGun: an untrained method for the prediction of protein stability changes upon single and multiple point variations (https://doi.org/10.1186/s12859-019-2923-1)


### TODO
DDGun for 
